<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = get_option( 'stylesheet' );
	$themename = preg_replace( "/\W/", "_", strtolower( $themename ) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'retrolin'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {

	// If using image radio buttons, define a directory path
	$imagepath =  trailingslashit( get_template_directory_uri() ) . 'images/';

	// Background Defaults
	$background_defaults = array(
		'color' => '#5c4833',
		'image' => $imagepath . 'main_header.jpg',
		'repeat' => 'repeat',
		'position' => 'top left',
		'attachment'=>'scroll' );

	// Editor settings
	$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress' )
	);

	// Footer Position settings
	$footer_position_settings = array(
		'left' => esc_html__( 'Left aligned', 'retrolin' ),
		'center' => esc_html__( 'Center aligned', 'retrolin' ),
		'right' => esc_html__( 'Right aligned', 'retrolin' )
	);

	$options = array();

	$options[] = array(
		'name' => esc_html__( 'Basic Settings', 'retrolin' ),
		'type' => 'heading' );

	$options[] = array(
		'name' => esc_html__( 'Background', 'retrolin' ),
		'desc' => sprintf( wp_kses( __( 'If you&rsquo;d like to replace or remove the default background image, use the <a href="%1$s" title="Custom background">Appearance &gt; Background</a> menu option.', 'retrolin' ), array(
			'a' => array( 
				'href' => array(),
				'title' => array() )
			) ), admin_url( 'themes.php?page=custom-background' ) ),
		'type' => 'info' );

	$options[] = array(
		'name' => esc_html__( 'Logo', 'retrolin' ),
		'desc' => sprintf( wp_kses( __( 'If you&rsquo;d like to replace or remove the default logo, use the <a href="%1$s" title="Custom header">Appearance &gt; Header</a> menu option.', 'retrolin' ), array(
			'a' => array( 
				'href' => array(),
				'title' => array() )
			) ), admin_url( 'themes.php?page=custom-header' ) ),
		'type' => 'info' );

//	$options[] = array(
//		'name' => esc_html__( 'Social Media Settings', 'retrolin' ),
//		'desc' => esc_html__( 'Enter the URLs for your Social Media platforms. You can also optionally specify whether you want these links opened in a new browser tab/window.', 'retrolin' ),
//		'type' => 'info' );
//
//	$options[] = array(
//		'name' => esc_html__('Open links in new Window/Tab', 'retrolin'),
//		'desc' => esc_html__('Open the social media links in a new browser tab/window', 'retrolin'),
//		'id' => 'social_newtab',
//		'std' => '0',
//		'type' => 'checkbox');
//
//	$options[] = array(
//		'name' => esc_html__( 'Twitter', 'retrolin' ),
//		'desc' => esc_html__( 'Enter your Twitter URL.', 'retrolin' ),
//		'id' => 'social_twitter',
//		'std' => '',
//		'type' => 'text' );
//
//	$options[] = array(
//		'name' => esc_html__( 'Facebook', 'retrolin' ),
//		'desc' => esc_html__( 'Enter your Facebook URL.', 'retrolin' ),
//		'id' => 'social_facebook',
//		'std' => '',
//		'type' => 'text' );
//
//	$options[] = array(
//		'name' => esc_html__( 'Google+', 'retrolin' ),
//		'desc' => esc_html__( 'Enter your Google+ URL.', 'retrolin' ),
//		'id' => 'social_googleplus',
//		'std' => '',
//		'type' => 'text' );
//
//	$options[] = array(
//		'name' => esc_html__( 'LinkedIn', 'retrolin' ),
//		'desc' => esc_html__( 'Enter your LinkedIn URL.', 'retrolin' ),
//		'id' => 'social_linkedin',
//		'std' => '',
//		'type' => 'text' );
//
//	$options[] = array(
//		'name' => esc_html__( 'YouTube', 'retrolin' ),
//		'desc' => esc_html__( 'Enter your YouTube URL.', 'retrolin' ),
//		'id' => 'social_youtube',
//		'std' => '',
//		'type' => 'text' );
//
//	$options[] = array(
//		'name' => esc_html__( 'Instagram', 'retrolin' ),
//		'desc' => esc_html__( 'Enter your Instagram URL.', 'retrolin' ),
//		'id' => 'social_instagram',
//		'std' => '',
//		'type' => 'text' );
//
//	$options[] = array(
//		'name' => esc_html__( 'Flickr', 'retrolin' ),
//		'desc' => esc_html__( 'Enter your Flickr URL.', 'retrolin' ),
//		'id' => 'social_flickr',
//		'std' => '',
//		'type' => 'text' );
//
//	$options[] = array(
//		'name' => esc_html__( 'Pinterest', 'retrolin' ),
//		'desc' => esc_html__( 'Enter your Pinterest URL.', 'retrolin' ),
//		'id' => 'social_pinterest',
//		'std' => '',
//		'type' => 'text' );

	$options[] = array(
		'name' => esc_html__( 'Advanced settings', 'retrolin' ),
		'type' => 'heading' );

	$options[] = array(
        'name' =>  esc_html__( 'Header Image', 'retrolin' ),
        'desc' => esc_html__( 'Select an    image and background color for the homepage banner.', 'retrolin' ),
        'id' => 'header_image',
        'std' => $background_defaults,
        'type' => 'background' );

	$options[] = array(
		'name' => esc_html__( 'Footer Background Color', 'retrolin' ),
		'desc' => esc_html__( 'Select the background color for the footer.', 'retrolin' ),
		'id' => 'footer_color',
		'std' => '#FFFFFF',
		'type' => 'color' );

	$options[] = array(
		'name' => esc_html__( 'Footer Content', 'retrolin' ),
		'desc' => esc_html__( 'Enter the text you&lsquo;d like to display in the footer. This content will be displayed just below the footer widgets. It&lsquo;s ideal for displaying your copyright message or credits.', 'retrolin' ),
		'id' => 'footer_content',
		'std' => retrolin_get_credits(),
		'type' => 'editor',
		'settings' => $wp_editor_settings );

	$options[] = array(
		'name' => esc_html__( 'Footer Content Position', 'retrolin' ),
		'desc' => esc_html__( 'Select what position you would like the footer content aligned to.', 'retrolin' ),
		'id' => 'footer_position',
		'std' => 'center',
		'type' => 'select',
		'class' => 'mini',
		'options' => $footer_position_settings );

	return $options;
}
